@@ -78,7 +78,6 @@ def debug():
     else:
         return version() == "unknown" and not _inside_docker()
 
-
 def log_level() -> int:
     log_levels = {
         "INFO": logging.INFO,
@@ -194,9 +193,9 @@ def testing():
 
 
 def database_folder() -> str:
-    path = string("DATABASE_FOLDER", f"../sqlite/")
+    path = string("DATABASE_FOLDER", f"/data/sqlite/")
     if testing():
-        path += "test/"
+        path = "../sqlite/test/"
     elif debug():
-        path += "debug/"
+        path = "../sqlite/debug/"
     return path
