@@ -4,11 +4,8 @@ from alembic import context
 from sqlalchemy import engine_from_config
 from sqlalchemy import pool
 
-from openmodule.database.database import target_metadata
-
 # this is the Alembic Config object, which provides
 # access to the values within the .ini file in use.
-
 config = context.config
 
 # Interpret the config file for Python logging.
@@ -16,26 +13,10 @@ config = context.config
 if config.attributes.get('configure_logging', True):
     fileConfig(config.config_file_name)
 
+target_metadata = config.attributes["target_metadata"]
 
-# add your model's MetaData object here
-# for 'autogenerate' support
-# from myapp import mymodel
-# target_metadata = mymodel.Base.metadata
-
-
-# other values from the config, defined by the needs of env.py,
-# can be acquired:
-# my_important_option = config.get_main_option("my_important_option")
-# ... etc.
 
 def run_migrations_online():
-    """Run migrations in 'online' mode.
-
-    In this scenario we need to create an Engine
-    and associate a connection with the context.
-
-    """
-
     def process_revision_directives(context, revision, directives):
         if config.cmd_opts.autogenerate:
             script = directives[0]
