@@ -1,5 +1,6 @@
-from typing import Optional, List
+from typing import Optional, List, Iterable, Union
 
+from openmodule.models.backend import MediumType
 from openmodule.models.base import OpenModuleModel
 
 
@@ -12,7 +13,7 @@ def _truncate(x):
 
 class Medium(OpenModuleModel):
     id: str
-    type: str
+    type: MediumType
 
     def __str__(self):
         return f"{self.type}:{_truncate(self.id)}"
@@ -46,6 +47,19 @@ class Vehicle(OpenModuleModel):
     nfc: Optional[Medium]
     pin: Optional[Medium]
 
+    def iterate_media(self) -> Iterable[Union[Medium, LPRMedium]]:
+        """
+        an iterable of all media of this vehicle
+        """
+        if self.lpr:
+            yield self.lpr
+        if self.qr:
+            yield self.qr
+        if self.nfc:
+            yield self.nfc
+        if self.pin:
+            yield self.pin
+
     def __str__(self):
         media = ", ".join(str(x) for x in [self.lpr, self.qr, self.nfc] if x)
         return f"Vehicle<id:{str(self.id)[-7:]}, {media}>"
