@@ -1,3 +1,4 @@
+import logging
 from enum import Enum
 from urllib.parse import urljoin
 
@@ -6,7 +7,7 @@ from requests.auth import HTTPBasicAuth, HTTPDigestAuth
 
 
 class ApiException(Exception):
-    def __init__(self, status_code, msg=""):
+    def __init__(self, status_code, msg="", response=None):
         if status_code in [503, 412, 500, 408]:
             retry = True
         else:
@@ -14,6 +15,7 @@ class ApiException(Exception):
         self.status = status_code
         self.msg = msg
         self.retry = retry
+        self.response = response
 
     def __str__(self):
         return f"Api Error {self.status}: {self.msg}"
@@ -53,11 +55,13 @@ class Api:
         return {}
 
     def _request(self, method, url, payload=None, json_response=True, **kwargs):
-        url = urljoin(self.server_host, url)
+        url = f"{self.server_host.rstrip('/')}/{url}"
         timeout = kwargs.pop("timeout", self.request_timeout)
         headers = self._common_headers()
         headers.update(kwargs.pop("headers", {}))
+        result = None
         try:
+            logging.debug(f"Sending {method} request to {url}")
             result = requests.request(method.upper(), url, **kwargs, timeout=timeout, headers=headers,
                                       verify=self.verify_ssl, json=payload, auth=self.auth)
             if 200 <= result.status_code < 300:
@@ -67,8 +71,8 @@ class Api:
         except requests.Timeout:
             raise ApiException(status_code=408, msg=f"Timeout after {timeout}s")
         except Exception as e:
-            raise ApiException(status_code=400, msg=str(e))
-        raise ApiException(status_code=result.status_code, msg="Server error")
+            raise ApiException(status_code=400, msg=str(e), response=result)
+        raise ApiException(status_code=result.status_code, msg="Server error", response=result)
 
     def get(self, url, payload=None, json_response=True, **kwargs):
         return self._request("GET", url, payload, json_response, **kwargs)
