@@ -1,15 +1,15 @@
 import time
 
-from openmodule.utils.backend.backend import Backend
-from openmodule.utils.backend.models import AccessRequest, CountMessage, Access
+from openmodule.utils.backend import Backend
+from openmodule.models.backend import AccessRequest, CountMessage, Access
 from openmodule.core import core
-from openmodule.models import Gateway
+from openmodule.models.base import Gateway
 from openmodule_test.core import OpenModuleCoreTestMixin
 from openmodule_test.eventlistener import MockEvent
 
 
 class TestBackend(Backend):
-    __test__ = False # otherwise pytest thinks this is a testcase
+    __test__ = False  # otherwise pytest thinks this is a testcase
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -44,20 +44,19 @@ class TestBackend(Backend):
             raise Exception("test_exception")
         if request.gateway.gate == "empty":
             return []
-        return [Access(category="permanent-employee", start=time.time() - 1000, user="user")]
+        return [Access(category="permanent-employee", start=time.time() - 1000,
+                       end=time.time() + 3600 * 24 * 7, user="user")]
 
 
 class BackendTestMixin(OpenModuleCoreTestMixin):
     """
     BackendTestMixin with helper functions for testing backends
-    * set the backend and a USER_PREFIX
+    * set the backend_class
     """
     backend_class = None
-    USER_PREFIX = None
 
     @classmethod
     def setUpClass(cls) -> None:
-        assert cls.USER_PREFIX is not None, "set a valid USER_PREFIX"
         assert cls.backend_class, "set a backend_class"
         return super().setUpClass()
 
@@ -94,7 +93,7 @@ class BackendTestMixin(OpenModuleCoreTestMixin):
         request = self.create_access_request(**kwargs)
         return self.backend.rpc_check_access(request, None)
 
-    def create_count_message(self, transaction_id=None, *, resource="arivotest", user="user", gate="gate1",
+    def create_count_message(self, transaction_id=None, *, resource="arivotest", user="api-backend_user", gate="gate1",
                              direction="in", medium="lpr",
                              medium_id="GARIVO1", zone="zone1", category="permanent-employee", correction=False,
                              error=None, **kwargs):
@@ -113,7 +112,6 @@ class BackendTestMixin(OpenModuleCoreTestMixin):
         :param kwargs: Additional parameters for errors, should not be used directly
         :return: transaction_id
         """
-        user = f"api-{self.USER_PREFIX}_{user}"
         gateway = Gateway(gate=gate, direction=direction)
         if transaction_id is None:
             transaction_id = f"transaction-{self.transaction_count}"
@@ -215,14 +213,13 @@ class BackendTestMixin(OpenModuleCoreTestMixin):
         message.id = medium_id
         return self.check_out(transaction_id)
 
-    def check_out_user_changed(self, transaction_id, user="user1") -> CountMessage:
+    def check_out_user_changed(self, transaction_id, user="api-backend_user1") -> CountMessage:
         """ check_out call with changed user
             :param transaction_id: Transaction ID of the check_in message
             :param user: new user
             """
         message = self.messages_by_transaction[transaction_id]
         message.previous_user = message.user
-        user = f"api-{self.USER_PREFIX}_{user}"
         assert user != message.user, "user needs to change"
         message.user = user
         message.error = "user_changed"
