@@ -5,8 +5,14 @@ from openmodule_test.health import HealthTestMixin
 
 
 class OpenModuleCoreTestMixin(HealthTestMixin):
+    """
+    Mixin which creates a core, zmq, and health mixin
+    config-priority: config_kwargs -> zmq_config -> base_config, afterwards always use core.config
+    """
+
     init_kwargs: Dict = {}
     config_kwargs: Dict = {}
+    base_config = None
 
     core: OpenModuleCore
 
@@ -16,17 +22,25 @@ class OpenModuleCoreTestMixin(HealthTestMixin):
     def get_init_kwargs(self):
         return self.init_kwargs
 
+    def _fake_config(self):
+        conf = self.zmq_config(**self.get_config_kwargs())
+        if self.base_config:
+            for key in vars(self.base_config):
+                if not key.startswith("_") and key not in vars(conf):
+                    setattr(conf, key, getattr(self.base_config, key))
+        return conf
+
     def setUp(self):
         super().setUp()
         self.init_kwargs.setdefault("sentry", False)
         self.init_kwargs.setdefault("dsgvo", False)
         self.core = init_openmodule(
-            config=self.zmq_config(**self.get_config_kwargs()),
+            config=self._fake_config(),
             context=self.zmq_context(),
             **self.get_init_kwargs()
         )
         self.zmq_client.subscribe(b"healthz")
-        self.wait_for_health(self.zmq_config().NAME)
+        self.wait_for_health(self.core.config.NAME)
 
     def tearDown(self):
         try:
