@@ -5,7 +5,7 @@ from unittest import TestCase
 import orjson
 from pydantic import ValidationError
 
-from openmodule.models import OpenModuleModel, ZMQMessage, Gateway
+from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway
 
 
 class TestModel(OpenModuleModel):
