@@ -3,7 +3,7 @@ from unittest import TestCase
 import json
 from textwrap import dedent
 
-from openmodule.models.backend import CountMessage, AccessRequest, Access, Category, check_recurrence
+from openmodule.models.backend import CountMessage, AccessRequest, Access, AccessCategory, check_recurrence
 from openmodule.models.base import Gateway
 from openmodule.rpc.server import RPCServer
 from openmodule.utils.backend import Backend
@@ -121,8 +121,8 @@ class ModelTest(TestCase):
 
     def test_category(self):
         with self.assertRaises(Exception) as e:
-            Category("test_exception")
-        self.assertIn("not a valid category", str(e.exception).lower())
+            AccessCategory("test_exception")
+        self.assertIn("is not a valid accesscategory", str(e.exception).lower())
 
         with self.assertRaises(Exception) as e:
             Access(user="asdf", category="permanent_employee", start=3,
@@ -289,39 +289,33 @@ class RpcTest(BackendTestMixin, RPCServerTestMixin, TestCase):
         self.assertEqual("register", message["type"])
 
     def test_check_in(self):
-        with self.assertLogs() as cm:
-            self.send_count_message()
-            self.backend.wait_for_message_process()
+        self.send_count_message()
+        self.backend.wait_for_message_process()
         self.assertEqual(1, self.backend.checked_in)
-        self.assertIn("successful", cm.output[0])
 
         MockEvent.reset_all_call_counts()
         with self.assertLogs() as cm:
             self.send_count_message(gate="error")
             self.backend.wait_for_message_process()
         self.assertEqual(1, self.backend.checked_in)
-        self.assertIn("failed", cm.output[0])
+        self.assertIn("error in check_in", cm.output[0])
 
     def test_check_out(self):
-        with self.assertLogs() as cm:
-            self.send_count_message()
-            self.backend.wait_for_message_process()
+        self.send_count_message()
+        self.backend.wait_for_message_process()
         self.assertEqual(1, self.backend.checked_in)
-        self.assertIn("successful", cm.output[0])
 
         MockEvent.reset_all_call_counts()
         with self.assertLogs() as cm:
             self.send_count_message(gate="error", direction="out")
             self.backend.wait_for_message_process()
         self.assertEqual(1, self.backend.checked_in)
-        self.assertIn("failed", cm.output[0])
+        self.assertIn("error in check_out", cm.output[0])
 
         MockEvent.reset_all_call_counts()
-        with self.assertLogs() as cm:
-            self.send_count_message(direction="out")
-            self.backend.wait_for_message_process()
+        self.send_count_message(direction="out")
+        self.backend.wait_for_message_process()
         self.assertEqual(0, self.backend.checked_in)
-        self.assertIn("successful", cm.output[0])
 
     def test_datetime_is_converted_to_unix_timestamp(self):
         gateway = Gateway(gate="entry", direction="in")
