@@ -1,8 +1,14 @@
+from functools import partial
+
+import orjson
+from typing import Optional
+
 import time
 from unittest import TestCase
 
 from openmodule.core import init_openmodule, shutdown_openmodule
 from openmodule.models.base import Direction
+from openmodule.models.presence import PresenceBaseMessage
 from openmodule.utils.presence import PresenceListener
 from openmodule_test.eventlistener import MockEvent
 from openmodule_test.presence import PresenceSimulator
@@ -175,3 +181,18 @@ class GateFilterTest(BasePresenceTest):
             self.on_enter2.wait_for_call()
 
         self.assertEqual({}, self.presence2.present_vehicles)
+
+
+class PresenceSimulatorTest(TestCase):
+    message: Optional[PresenceBaseMessage] = None
+
+    def setUp(self) -> None:
+        super().setUp()
+        self.message = None
+
+    def test_presence_alias_fields_serialization(self):
+        sim = PresenceSimulator("gate1", Direction.IN, partial(setattr, self, "message"))
+        sim.enter(sim.vehicle().qr("test"))
+        sim.forward()
+        message = orjson.loads(self.message.json_bytes())
+        self.assertIn("leave-time", message)
